FUSE kernel interface.
Types and definitions used for communication between the kernel driver and the userspace part of a FUSE filesystem. Since the kernel driver may be installed independently, the ABI interface is versioned and capabilities are exchanged during the initialization (mounting) of a filesystem.
OSXFUSE (macOS): https://github.com/osxfuse/fuse/blob/master/include/fuse_kernel.h
- supports ABI 7.8 in OSXFUSE 2.x
- supports ABI 7.19 since OSXFUSE 3.0.0
libfuse (Linux/BSD): https://github.com/libfuse/libfuse/blob/master/include/fuse_kernel.h
- supports ABI 7.8 since FUSE 2.6.0
- supports ABI 7.12 since FUSE 2.8.0
- supports ABI 7.18 since FUSE 2.9.0
- supports ABI 7.19 since FUSE 2.9.1
- supports ABI 7.26 since FUSE 3.0.0
Items without a version annotation are valid with ABI 7.8 and later
Modules
Structs
- Invalid
Notify Code Error - Invalid notify code error.
- Invalid
Opcode Error - Invalid opcode error.
- cuse_
init_ in - cuse_
init_ out - fuse_
access_ in - fuse_
attr - fuse_
attr_ out - fuse_
batch_ forget_ in - fuse_
bmap_ in - fuse_
bmap_ out - fuse_
create_ in - fuse_
dirent - fuse_
direntplus - fuse_
entry_ out - fuse_
fallocate_ in - fuse_
file_ lock - fuse_
flush_ in - fuse_
forget_ in - fuse_
forget_ one - fuse_
fsync_ in - fuse_
getattr_ in - fuse_
getxattr_ in - fuse_
getxattr_ out - fuse_
in_ header - fuse_
init_ in - fuse_
init_ out - fuse_
init_ out_ 22 - fuse_
interrupt_ in - fuse_
ioctl_ in - fuse_
ioctl_ iovec - fuse_
ioctl_ out - fuse_
kstatfs - fuse_
link_ in - fuse_
lk_ in - fuse_
lk_ out - fuse_
lseek_ in - fuse_
lseek_ out - fuse_
mkdir_ in - fuse_
mknod_ in - fuse_
notify_ delete_ out - fuse_
notify_ inval_ entry_ out - fuse_
notify_ inval_ inode_ out - fuse_
notify_ poll_ wakeup_ out - fuse_
notify_ retrieve_ in - fuse_
notify_ retrieve_ out - fuse_
notify_ store_ out - fuse_
open_ in - fuse_
open_ out - fuse_
out_ header - fuse_
poll_ in - fuse_
poll_ out - fuse_
read_ in - fuse_
release_ in - fuse_
rename2_ in - fuse_
rename_ in - fuse_
setattr_ in - fuse_
setxattr_ in - fuse_
statfs_ out - fuse_
write_ in - fuse_
write_ out